Crate fenrix

Crate fenrix 

Fenrix

A modern Rust UI framework for building fast, reliable, and beautiful web apps.

This crate is the main entry point for the Fenrix framework, re-exporting all the necessary components from the various internal crates.

Re-exports

pub use wasm_bindgen;
pub use web_sys;

Macros

rsx

Structs

Router

Functions

create_effect
Creates an effect that re-runs when its dependencies change.
create_signal
A reactive signal that holds a value.
inject
Injects a service from the global DI container.
provide_router
Provides a router instance to the application.
provide_service
Provides a service to the application’s global DI container.
render
Renders a root node to the document body.
use_effect
Creates an effect that runs once and re-runs when its dependencies change.
use_router
A hook to get the current router instance from the DI container.
use_state
Provides a piece of state for a component.
with_component_context
A helper function to be called by the #[component] macro.

Type Aliases

Routable

Attribute Macros

component